package com.javaair.entities;

import java.io.Serializable;
import javax.persistence.*;
import java.util.List;


/**
 * The persistent class for the AIRPORT database table.
 * 
 */
@Entity
@Table(name="AIRPORT", schema="JAVAAIR")
@NamedQueries({@NamedQuery(name="Airport.findAll", query = "SELECT airports FROM Airport airports"),
	@NamedQuery(name= "Airport.findByAirportId", query = "SELECT airports from Airport airports where airports.airportId = :airport")
})
public class Airport implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@SequenceGenerator(name="AIRPORT_SID_GENERATOR", sequenceName="JAVAAIR.SEQ_AIRPORT", allocationSize = 1)
	@GeneratedValue(strategy=GenerationType.SEQUENCE, generator="AIRPORT_SID_GENERATOR")
	@Column(unique=true, nullable=false)
	private int sid;

	@Column(name="AIRPORT_ID", nullable=false, length=50)
	private String airportId;

	@Column(nullable=false, length=50)
	private String city;

	@Column(nullable=false, length=50)
	private String name;

	@Column(nullable=false, length=50)
	private String state;

	//bi-directional many-to-one association to Route
	@OneToMany(mappedBy="destination")
	private List<Route> routeDestinations;

	//bi-directional many-to-one association to Route
	@OneToMany(mappedBy="origin")
	private List<Route> routeOrigins;

	//bi-directional many-to-one association to TicketRoute
	@OneToMany(mappedBy="tripDestination")
	private List<TicketRoute> ticketRouteDestinations;

	//bi-directional many-to-one association to TicketRoute
	@OneToMany(mappedBy="tripSource")
	private List<TicketRoute> ticketRouteSources;

	//bi-directional many-to-one association to TicketUnit
	@OneToMany(mappedBy="destination")
	private List<TicketUnit> ticketUnitDestinations;

	//bi-directional many-to-one association to TicketUnit
	@OneToMany(mappedBy="origin")
	private List<TicketUnit> ticketUnitOrigins;

    public Airport() {
    }

	public int getSid() {
		return this.sid;
	}

	public void setSid(int sid) {
		this.sid = sid;
	}

	public String getAirportId() {
		return this.airportId;
	}

	public void setAirportId(String airportId) {
		this.airportId = airportId;
	}

	public String getCity() {
		return this.city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getName() {
		return this.name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getState() {
		return this.state;
	}

	public void setState(String state) {
		this.state = state;
	}

	public List<Route> getRoutes1() {
		return this.routeDestinations;
	}

	public void setRoutes1(List<Route> routes1) {
		this.routeDestinations = routes1;
	}
	
	public List<Route> getRoutes2() {
		return this.routeOrigins;
	}

	public void setRoutes2(List<Route> routes2) {
		this.routeOrigins = routes2;
	}
	
	public List<TicketRoute> getTicketRoutes1() {
		return this.ticketRouteDestinations;
	}

	public void setTicketRoutes1(List<TicketRoute> ticketRoutes1) {
		this.ticketRouteDestinations = ticketRoutes1;
	}
	
	public List<TicketRoute> getTicketRoutes2() {
		return this.ticketRouteSources;
	}

	public void setTicketRoutes2(List<TicketRoute> ticketRoutes2) {
		this.ticketRouteSources = ticketRoutes2;
	}
	
	public List<TicketUnit> getTicketUnits1() {
		return this.ticketUnitDestinations;
	}

	public void setTicketUnits1(List<TicketUnit> ticketUnits1) {
		this.ticketUnitDestinations = ticketUnits1;
	}
	
	public List<TicketUnit> getTicketUnits2() {
		return this.ticketUnitOrigins;
	}

	public void setTicketUnits2(List<TicketUnit> ticketUnits2) {
		this.ticketUnitOrigins = ticketUnits2;
	}
	
}