package com.javaair.entities;

import java.io.Serializable;
import javax.persistence.*;
import java.util.List;

/**
 * The persistent class for the FLIGHT database table.
 * 
 */
@Entity
@Table(name = "FLIGHT", schema = "JAVAAIR")
// @NamedQuery(name= "Flight.findAll",
// query="Select flights FROM Flight flights")
@NamedQueries({
	@NamedQuery(name = "Flight.findByDepartureDate", query = "Select flights FROM " +
		"Flight flights JOIN FETCH flights.scheduleBean " +
		"JOIN FETCH flights.routeBean WHERE " +
		"flights.scheduleBean.departureTime LIKE :departure " +
		"AND flights.routeBean.origin.airportId = :origin " +
		"AND flights.routeBean.destination.airportId = :destination"),
	@NamedQuery(name= "Flight.findByArrivalDate", query ="Select flights FROM " +
		"Flight flights JOIN FETCH flights.scheduleBean " +
		"JOIN FETCH flights.routeBean WHERE " +
		"flights.scheduleBean.arrivalTime LIKE :arrival " +
		"AND flights.routeBean.origin.airportId = :destination " +
		"AND flights.routeBean.destination.airportId = :origin"),
	@NamedQuery(name= "Flight.findSeatsByPlane", query="Select flights FROM Flight flights JOIN FETCH flights.planeBean WHERE flights.planeBean.sid = :planeSid")

})

public class Flight implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@SequenceGenerator(name = "FLIGHT_SID_GENERATOR", sequenceName = "JAVAAIR.SEQ_FLIGHT", allocationSize = 1)
	@GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "FLIGHT_SID_GENERATOR")
	@Column(unique = true, nullable = false)
	private int sid;

	@Column(name = "FLIGHT_ID", nullable = false, length = 50)
	private String flightId;

	// bi-directional many-to-one association to Plane
	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "PLANE", nullable = false)
	private Plane planeBean;

	// bi-directional many-to-one association to Route
	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "ROUTE", nullable = false)
	private Route routeBean;

	// bi-directional many-to-one association to Schedule
	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "SCHEDULE", nullable = false)
	private Schedule scheduleBean;

	// bi-directional many-to-one association to TicketRoute
	@OneToMany(mappedBy = "flightBean")
	private List<TicketRoute> ticketRoutes;

	// bi-directional many-to-one association to TicketUnit
	@OneToMany(mappedBy = "flightBean")
	private List<TicketUnit> ticketUnits;

	public Flight() {
	}

	public int getSid() {
		return this.sid;
	}

	public void setSid(int sid) {
		this.sid = sid;
	}

	public String getFlightId() {
		return this.flightId;
	}

	public void setFlightId(String flightId) {
		this.flightId = flightId;
	}

	public Plane getPlaneBean() {
		return this.planeBean;
	}

	public void setPlaneBean(Plane planeBean) {
		this.planeBean = planeBean;
	}

	public Route getRouteBean() {
		return this.routeBean;
	}

	public void setRouteBean(Route routeBean) {
		this.routeBean = routeBean;
	}

	public Schedule getScheduleBean() {
		return this.scheduleBean;
	}

	public void setScheduleBean(Schedule scheduleBean) {
		this.scheduleBean = scheduleBean;
	}

	public List<TicketRoute> getTicketRoutes() {
		return this.ticketRoutes;
	}

	public void setTicketRoutes(List<TicketRoute> ticketRoutes) {
		this.ticketRoutes = ticketRoutes;
	}

	public List<TicketUnit> getTicketUnits() {
		return this.ticketUnits;
	}

	public void setTicketUnits(List<TicketUnit> ticketUnits) {
		this.ticketUnits = ticketUnits;
	}

}