package com.javaair.entities;

import java.io.Serializable;
import javax.persistence.*;

import java.util.List;


/**
 * The persistent class for the TICKET_ROUTE database table.
 * 
 */
@Entity
@Table(name="TICKET_ROUTE", schema="JAVAAIR")
@NamedQueries({@NamedQuery(name="TicketRoute.getTicketRouteSequence", query ="SELECT ticketroutes FROM TicketRoute ticketroutes " +
		"WHERE ticketroutes.sid = (SELECT MAX(ticketroutes.sid) FROM TicketRoute ticketroutes)"),
@NamedQuery(name="TicketRoute.getTicketRouteById", query ="SELECT ticketroutes FROM TicketRoute ticketroutes " +
		"WHERE ticketroutes.ticketRouteId = :ticketRouteId")		
})
public class TicketRoute implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@SequenceGenerator(name="TICKET_ROUTE_SID_GENERATOR", sequenceName="JAVAAIR.SEQ_TICKET_ROUTE", allocationSize = 1)
	@GeneratedValue(strategy=GenerationType.SEQUENCE, generator="TICKET_ROUTE_SID_GENERATOR")
	@Column(unique=true, nullable=false)
	private int sid;

	@Column(name="TICKET_ROUTE_ID", nullable=false, length=50)
	private String ticketRouteId;

	//bi-directional many-to-one association to Airport
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="TRIP_DESTINATION", nullable=false)
	private Airport tripDestination;

	//bi-directional many-to-one association to Airport
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="TRIP_SOURCE", nullable=false)
	private Airport tripSource;

	//bi-directional many-to-one association to Flight
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="FLIGHT", nullable=false)
	private Flight flightBean;

	//bi-directional many-to-one association to TicketSery
	@OneToMany(mappedBy="ticketRouteBean")
	private List<TicketSerie> ticketSeries;

	//bi-directional many-to-one association to TicketUnit
	@OneToMany(mappedBy="ticketRouteBean")
	private List<TicketUnit> ticketUnits;

    public TicketRoute() {
    }

	public int getSid() {
		return this.sid;
	}

	public void setSid(int sid) {
		this.sid = sid;
	}

	public String getTicketRouteId() {
		return this.ticketRouteId;
	}

	public void setTicketRouteId(String ticketRouteId) {
		this.ticketRouteId = ticketRouteId;
	}

	public Airport getAirport1() {
		return this.tripDestination;
	}

	public void setAirport1(Airport airport1) {
		this.tripDestination = airport1;
	}
	
	public Airport getAirport2() {
		return this.tripSource;
	}

	public void setAirport2(Airport airport2) {
		this.tripSource = airport2;
	}
	
	public Flight getFlightBean() {
		return this.flightBean;
	}

	public void setFlightBean(Flight flightBean) {
		this.flightBean = flightBean;
	}
	
	public List<TicketSerie> getTicketSeries() {
		return this.ticketSeries;
	}

	public void setTicketSeries(List<TicketSerie> ticketSeries) {
		this.ticketSeries = ticketSeries;
	}
	
	public List<TicketUnit> getTicketUnits() {
		return this.ticketUnits;
	}

	public void setTicketUnits(List<TicketUnit> ticketUnits) {
		this.ticketUnits = ticketUnits;
	}
	
}