package com.javaair.entities;

import java.io.Serializable;
import javax.persistence.*;
import java.util.Date;
import java.util.List;


/**
 * The persistent class for the TICKET_SERIES database table.
 * 
 */
@Entity
@Table(name="TICKET_SERIES", schema="JAVAAIR")
@NamedQueries({@NamedQuery(name ="TicketSerie.getTicketSerieSequence", query="SELECT ticketseries FROM TicketSerie ticketseries WHERE ticketseries.sid = (SELECT MAX(ticketseries.sid) FROM TicketSerie ticketseries)")
})
public class TicketSerie implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@SequenceGenerator(name="TICKET_SERIES_SID_GENERATOR", sequenceName="JAVAAIR.SEQ_TICKET_SERIES", allocationSize = 1)
	@GeneratedValue(strategy=GenerationType.SEQUENCE, generator="TICKET_SERIES_SID_GENERATOR")
	@Column(unique=true, nullable=false)
	private int sid;

    @Temporal( TemporalType.DATE)
	@Column(name="BOOK_DATE", nullable=false)
	private Date bookDate;

	@Column(name="TICKET_SERIES_ID", nullable=false, length=50)
	private String ticketSeriesId;

	//bi-directional many-to-one association to Passenger
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="PASSENGER", nullable=false)
	private Passenger passengerBean;

	//bi-directional many-to-one association to TicketRoute
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="TICKET_ROUTE", nullable=false)
	private TicketRoute ticketRouteBean;

	//bi-directional many-to-one association to TicketUnit
	@OneToMany(mappedBy="ticketSerie")
	private List<TicketUnit> ticketUnits;

    public TicketSerie() {
    }

	public int getSid() {
		return this.sid;
	}

	public void setSid(int sid) {
		this.sid = sid;
	}

	public Date getBookDate() {
		return this.bookDate;
	}

	public void setBookDate(Date bookDate) {
		this.bookDate = bookDate;
	}

	public String getTicketSeriesId() {
		return this.ticketSeriesId;
	}

	public void setTicketSeriesId(String ticketSeriesId) {
		this.ticketSeriesId = ticketSeriesId;
	}

	public Passenger getPassengerBean() {
		return this.passengerBean;
	}

	public void setPassengerBean(Passenger passengerBean) {
		this.passengerBean = passengerBean;
	}
	
	public TicketRoute getTicketRouteBean() {
		return this.ticketRouteBean;
	}

	public void setTicketRouteBean(TicketRoute ticketRouteBean) {
		this.ticketRouteBean = ticketRouteBean;
	}
	
	public List<TicketUnit> getTicketUnits() {
		return this.ticketUnits;
	}

	public void setTicketUnits(List<TicketUnit> ticketUnits) {
		this.ticketUnits = ticketUnits;
	}
	
}