package com.javaair.entities;

import java.io.Serializable;
import javax.persistence.*;


/**
 * The persistent class for the TICKET_UNIT database table.
 * 
 */
@Entity
@Table(name="TICKET_UNIT", schema="JAVAAIR")
public class TicketUnit implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@SequenceGenerator(name="TICKET_UNIT_SID_GENERATOR", sequenceName="JAVAAIR.SEQ_TICKET_UNIT", allocationSize = 1)
	@GeneratedValue(strategy=GenerationType.SEQUENCE, generator="TICKET_UNIT_SID_GENERATOR")
	@Column(unique=true, nullable=false)
	private int sid;

	@Column(name="FLIGHT_CLASS", nullable=false)
	private int flightClass;

	@Column(name="TICKET_ID", nullable=false, length=50)
	private String ticketId;

	//bi-directional many-to-one association to Airport
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="DESTINATION", nullable=false)
	private Airport destination;

	//bi-directional many-to-one association to Airport
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="ORIGIN", nullable=false)
	private Airport origin;

	//bi-directional many-to-one association to Flight
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="FLIGHT", nullable=false)
	private Flight flightBean;

	//bi-directional many-to-one association to Seat
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="SEAT", nullable=false)
	private Seat seatBean;

	//bi-directional many-to-one association to TicketRoute
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="TICKET_ROUTE", nullable=false)
	private TicketRoute ticketRouteBean;

	//bi-directional many-to-one association to TicketSery
	@ManyToOne(fetch=FetchType.LAZY)
	@JoinColumn(name="TICKET_SERIES", nullable=false)
	private TicketSerie ticketSerie;

    public TicketUnit() {
    }

	public int getSid() {
		return this.sid;
	}

	public void setSid(int sid) {
		this.sid = sid;
	}

	public int getFlightClass() {
		return this.flightClass;
	}

	public void setFlightClass(int flightClass) {
		this.flightClass = flightClass;
	}

	public String getTicketId() {
		return this.ticketId;
	}

	public void setTicketId(String ticketId) {
		this.ticketId = ticketId;
	}

	public Airport getAirport1() {
		return this.destination;
	}

	public void setAirport1(Airport airport1) {
		this.destination = airport1;
	}
	
	public Airport getAirport2() {
		return this.origin;
	}

	public void setAirport2(Airport airport2) {
		this.origin = airport2;
	}
	
	public Flight getFlightBean() {
		return this.flightBean;
	}

	public void setFlightBean(Flight flightBean) {
		this.flightBean = flightBean;
	}
	
	public Seat getSeatBean() {
		return this.seatBean;
	}

	public void setSeatBean(Seat seatBean) {
		this.seatBean = seatBean;
	}
	
	public TicketRoute getTicketRouteBean() {
		return this.ticketRouteBean;
	}

	public void setTicketRouteBean(TicketRoute ticketRouteBean) {
		this.ticketRouteBean = ticketRouteBean;
	}
	
	public TicketSerie getTicketSery() {
		return this.ticketSerie;
	}

	public void setTicketSery(TicketSerie ticketSery) {
		this.ticketSerie = ticketSery;
	}
	
}