package com.javaair.test;

import java.text.ParseException;
import java.util.List;
import java.util.Scanner;

import com.javaair.business.BAirport;
import com.javaair.business.BFlight;
import com.javaair.business.BPassenger;
import com.javaair.business.BTicketRoute;
import com.javaair.business.BTicketSerie;
import com.javaair.entities.Airport;
import com.javaair.entities.Flight;
import com.javaair.entities.Passenger;
import com.javaair.entities.Seat;
import com.javaair.entities.TicketRoute;
import com.javaair.entities.TicketSerie;
import com.javaair.vo.PassengerVO;
import com.javaair.vo.TicketRouteVO;

public class AirportTest {

	public static void main(String[] args) throws ParseException {

		// Business Classes
		BAirport ap = new BAirport();
		BFlight ft = new BFlight();
		BPassenger ps = new BPassenger();
		BTicketRoute tr = new BTicketRoute();
		BTicketSerie ts = new BTicketSerie();
		

		// Print application header
		System.out.println("      Java Air");
		System.out.println("Flight Booking System");
		System.out.println("");

		// Gather user data entry
		Scanner scan = new Scanner(System.in);
		System.out.print("From: ");

		String origin = scan.nextLine();

		System.out.println("To: ");

		String destination = scan.nextLine();

		System.out.print("Please insert a departure date: ");

		String departure = scan.nextLine();

		System.out.print("Please insert a return date: ");

		String arrival = scan.nextLine();

		// Search for outward flights by departure date.

		List<Flight> flights = ft.findByDepartureDate(departure, origin,
				destination);

		System.out.println("Departure Flights: ");
		System.out
				.println("        Flight             Departure              Arrival        From:  To:");

		for (Flight flight : flights) {
			System.out.println("["
					+ flight.getSid()
					+ "] "
					+ flight.getFlightId()
					+ " | "
					+ flight.getScheduleBean().getDepartureTime()
							.replace(".000000", "")
					+ " | "
					+ flight.getScheduleBean().getArrivalTime()
							.replace(".000000", "") + " | "
					+ flight.getRouteBean().getAirport2().getAirportId()
					+ " | "
					+ flight.getRouteBean().getAirport1().getAirportId());
		}

		// Capture desired outward flight id.
		System.out.println(" ");
		System.out.println("Enter Desired Outward Flight Id: ");
		String outwardFlightId = scan.nextLine();

		// Search for outward plane id and flight date
		Integer outwardPlaneId = 0;
		String outwardFlightDepartureDate = null;
		String outwardFlightArrivalDate = null;

		for (Flight flight : flights) {
			if (flight.getSid() == Integer.valueOf(outwardFlightId)) {
				outwardPlaneId = flight.getPlaneBean().getSid();
				outwardFlightDepartureDate = flight.getScheduleBean().getDepartureTime();
				outwardFlightArrivalDate = flight.getScheduleBean().getArrivalTime();
				break;
			}
		}

		// Search for return flights by arrival date.

		List<Flight> arrivalflights = ft.findByArrivalDate(arrival, origin,
				destination);

		System.out.println(" ");

		System.out.println("Arrival Flights: ");
		System.out
				.println("         Flight             Departure              Arrival        From:  To:");

		for (Flight flight : arrivalflights) {

			System.out.println("["
					+ flight.getSid()
					+ "] "
					+ flight.getFlightId()
					+ " | "
					+ flight.getScheduleBean().getDepartureTime()
							.replace(".000000", "")
					+ " | "
					+ flight.getScheduleBean().getArrivalTime()
							.replace(".000000", "") + " | "
					+ flight.getRouteBean().getAirport2().getAirportId()
					+ " | "
					+ flight.getRouteBean().getAirport1().getAirportId());
		}

		// Capture desired return flight id.
		System.out.println(" ");
		System.out.println("Enter Desired Return Flight Id: ");
		String returnFlightId = scan.nextLine();

		// Search for return plane id
		Integer returnPlaneId = 0;
		String returnFlightArrivalDate = null;
		String returnFlightDepartureDate = null;
		for (Flight flight : arrivalflights) {
			if (flight.getSid() == Integer.valueOf(returnFlightId)) {
				returnPlaneId = flight.getPlaneBean().getSid();
				returnFlightDepartureDate = flight.getScheduleBean().getDepartureTime();
				returnFlightArrivalDate = flight.getScheduleBean().getArrivalTime();
				break;
			}
		}

		// Flight's selection confirmation.
		System.out.println("");
		System.out.println("You have selected the flights outward: [" + origin
				+ "->" + destination + ": " + outwardFlightId + "] return: ["
				+ destination + "->" + origin + ": " + returnFlightId + "]");

		// Search for available seats on outward flight.
		System.out.println("");
		System.out.println("Available seats for flight: " + origin + " -> "
				+ destination + ": " + outwardFlightId);

		List<Flight> availableOutwardSeats = ft
				.findSeatsByPlane(outwardPlaneId);

		for (Flight flight : availableOutwardSeats) {
			for (Seat seats : flight.getPlaneBean().getSeats()) {
				System.out.println("    " + "[" + seats.getSid() + "] "
						+ seats.getSeatId());
			}
		}

		System.out.println("Enter Desired Seat for Outward Flight: ");
		String outwardSeatId = scan.nextLine();

		// Search for available seats on return flight.
		System.out.println("");
		System.out.println("Available seats for flight: " + destination
				+ " -> " + origin + ": " + returnFlightId);

		List<Flight> availableReturnSeats = ft.findSeatsByPlane(returnPlaneId);

		for (Flight flight : availableReturnSeats) {
			for (Seat seats : flight.getPlaneBean().getSeats()) {
				System.out.println("    " + "[" + seats.getSid() + "] "
						+ seats.getSeatId());
			}
		}

		System.out.println("Enter Desired Seat for Return Flight: ");
		String returnSeatId = scan.nextLine();

		// Summary

		System.out.println("You have selected the : [ Outward Flight #: "
				+ outwardFlightId + " ] [ From: " + origin + " - To: " + destination
				+ " ] [ Seat #: " + outwardSeatId + " ] [ Departure Date/Time: "
				+ outwardFlightDepartureDate.replace(".000000", "")
				+ " - Arrival Date/Time: "
				+ outwardFlightArrivalDate.replace(".000000", "")+" ]");
		
		System.out.println("");
		
		System.out.println("                      : [ Return Flight #: "
				+ returnFlightId + " ] [ From: " + destination + " - To: "
				+ origin + " ] [ Seat #: " + returnSeatId 
				+ " ] [ Departure Date/Time: "
				+ returnFlightDepartureDate.replace(".000000", "")
				+ " - Arrival Date/Time: "
				+ returnFlightArrivalDate.replace(".000000", "") + " ]");

		//Client information
		
		System.out.println("");
		System.out.println("Please provide the following information: ");
		System.out.println("");
		
		System.out.println("Name: ");
		String name = scan.nextLine();
		
		System.out.println("Last Name: ");
		String lastName = scan.nextLine();
		
		//Client Account Sequence Generation
		
		String accountNumber= null;
		int accountValue = 0;
		String accountValueInc = null;
		
		List<Passenger> accountSequence = ps.getAccountSequence();
		
		for (Passenger passenger : accountSequence){
			accountValue = Integer.valueOf(passenger.getAccountNumber().substring(5, 6));
		}
		
		accountValue++;
		
		accountValueInc = String.valueOf(accountValue);
		
		accountNumber = name.substring(0, 1).concat(lastName.substring(0, 1)).concat("000").concat(accountValueInc);
		
		System.out.println(accountNumber);
		
		//Persist Passenger
		
		PassengerVO t = new PassengerVO(name, lastName, accountNumber);
		ps.save(t);
		
		//Persist Ticket Route for Outward Flight
		//SDQALB00001
		
		List<TicketRoute> ticketRouteSequence = tr.getTicketRouteSequence();
		
		//Ticket Route Sequence Generation
		
		String ticketRouteId = null;
		int ticketRouteValue = 0;
		String ticketRouteValueInc = null;
		
		for (TicketRoute ticketroute : ticketRouteSequence){
			ticketRouteValue = Integer.valueOf(ticketroute.getTicketRouteId().substring(9, 10));
		}
		
		ticketRouteValue++;
		ticketRouteValueInc = String.valueOf(ticketRouteValue);
		
		ticketRouteId = origin.concat(destination).concat("000").concat(ticketRouteValueInc);
		
		//Find Outward Origin Airport Id
		
		int originAirportId = 0;
		
		List<Airport> airportIdOrigin = ap.findByAirportId(origin);
		
		for (Airport airport : airportIdOrigin){
			originAirportId = airport.getSid();
		}
		
		//Find Outward Destination Airport Id
		
		int destinationAirportId = 0;
		
		List<Airport> airportIdDestination = ap.findByAirportId(destination);
		
		for (Airport airport : airportIdDestination){
			destinationAirportId = airport.getSid();
		}
		
		int outwardFlightSid = Integer.valueOf(outwardFlightId);
		
		//Persist Outward Ticket Route
		
		System.out.println(ticketRouteId);
		TicketRouteVO ticketVO = new TicketRouteVO(ticketRouteId, outwardFlightSid, originAirportId, destinationAirportId);
		tr.save(ticketVO);
		
		//Persist Return Ticket Route
		
		//Return Ticket Route Sequence Generation
		
		List<TicketRoute> ticketRouteSequence2 = tr.getTicketRouteSequence();
		
		String ticketRouteId2 = null;
		int ticketRouteValue2 = 0;
		String ticketRouteValueInc2 = null;
		
		for (TicketRoute ticketroute : ticketRouteSequence2){
			ticketRouteValue2 = Integer.valueOf(ticketroute.getTicketRouteId().substring(9, 10));
		}
		
		ticketRouteValue2++;
		ticketRouteValueInc2 = String.valueOf(ticketRouteValue2);
		
		ticketRouteId2 = destination.concat(origin).concat("000").concat(ticketRouteValueInc2);
		
		//Find Return Origin Airport Id
		
		int originAirportId2 = 0;
		
		List<Airport> airportIdOrigin2 = ap.findByAirportId(destination);
		
		for (Airport airport : airportIdOrigin2){
			originAirportId2 = airport.getSid();
		}
		
		//Find Return Destination Airport Id
		
		int destinationAirportId2 = 0;
		
		List<Airport> airportIdDestination2 = ap.findByAirportId(origin);
		
		for (Airport airport : airportIdDestination2){
			destinationAirportId2 = airport.getSid();
		}
		
		int returnFlightSid = Integer.valueOf(returnFlightId);
		
		System.out.println(ticketRouteId2);
		TicketRouteVO ticketVO2 = new TicketRouteVO(ticketRouteId2, returnFlightSid, originAirportId2, destinationAirportId2);
		tr.save(ticketVO2);
		
		
		/* 
		 * Ticket Series Generation
		 */
		
		//Obtain Outward Ticket Route SID
		
		List<TicketRoute> outwardTicketRoute = tr.getTicketRouteById(ticketRouteId);
		
		int outwardTicketRouteSid = 0;
		
		for (TicketRoute ticketRoute : outwardTicketRoute){
			
			outwardTicketRouteSid = ticketRoute.getSid();
		}
		
		//Obtain Return Ticket Route SID
		
		List<TicketRoute> returnTicketRoute = tr.getTicketRouteById(ticketRouteId2);
		
		int returnTicketRouteSid = 0;
		
		for (TicketRoute ticketRoute : returnTicketRoute){
			
			returnTicketRouteSid = ticketRoute.getSid();
		}
		
		//Obtain Book Date from Departure Date Entered By User
		
		String bookDate = departure;
		
		/*
		 * To Do: Create Method to get the passenger's SID
		 * 		  Create Method to get the Ticket Series ID
		 */
		
		//Obtain Passenger SID
		int passengerSid = ps.getPassengerByAccount(accountNumber).getSid();
		
		//Generate Ticket Series ID
		
		List<TicketSerie> ticketSeriesSequence = ts.getTicketSerieSequence();
		
		String ticketSeriesId = null;
		int ticketSeriesValue = 0;
		String ticketSeriesValueInc = null;
		
		for (TicketSerie ticketSerie : ticketSeriesSequence){
			ticketSeriesValue = Integer.valueOf(ticketSerie.getTicketSeriesId().substring(9, 10));
		}
		
		ticketSeriesValue++;
		ticketSeriesValueInc = String.valueOf(ticketSeriesValue);
		
		ticketSeriesId = origin.concat(destination).concat("000").concat(ticketRouteValueInc);
		
	}
}
